[−][src]Attribute Macro celery_codegen::task
#[task]
A procedural macro for generating a Task from a function.
Parameters
name: The name to use when registering the task. Should be unique. If not given the name will be set to the name of the function being decorated.timeout: Corresponds toTask::timeout.max_retries: Corresponds toTask::max_retries.min_retry_delay: Corresponds toTask::min_retry_delay.max_retry_delay: Corresponds toTask::max_retry_delay.acks_late: Corresponds toTask::acks_late.